pub struct DelayLayer { /* private fields */ }Available on crate feature
tower-delay only.Expand description
A Tower Layer that introduces a fixed delay before each request.
Implementations
Sourceimpl DelayLayer
impl DelayLayer
Sourcepub const fn new(delay: Duration) -> Self
pub const fn new(delay: Duration) -> Self
Create a new DelayLayer with the given delay duration.
Sourcepub fn when<P, Req>(self, predicate: P) -> DelayLayerWith<P>
pub fn when<P, Req>(self, predicate: P) -> DelayLayerWith<P>
Apply delay only to requests that satisfy a predicate.
Requests that don’t match the predicate will pass through without delay.
Example
ⓘ
use std::time::Duration;
use http::Request;
use hpx_util::tower::delay::DelayLayer;
// Only delay POST requests
let layer = DelayLayer::new(Duration::from_secs(1))
.when(|req: &Request<_>| req.method() == http::Method::POST);Trait Implementations
Sourceimpl Clone for DelayLayer
impl Clone for DelayLayer
Sourcefn clone(&self) -> DelayLayer
fn clone(&self) -> DelayLayer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DelayLayer
impl Debug for DelayLayer